{ pkgs, lib, config, ... }:
{
  config = lib.mkIf config.frogeye.extra {
    programs = {
      pandoc.enable = true;
      yt-dlp = {
        enable = true;
        settings = {
          format = "bestvideo[height<=${builtins.toString config.frogeye.desktop.maxVideoHeight}]+bestaudio/best";
          sponsorblock-mark = "all";
          sponsorblock-remove = "intro,outro,sponsor,selfpromo,preview,interaction,music_offtopic";
          sub-langs = "en,fr";
          write-auto-subs = true;
          write-subs = true;
        };
      };
    };
    home.packages = with pkgs;  ([
      # android tools
      android-tools

      # Communication
      signal-desktop

      # downloading
      # transmission TODO Collision if both transmissions are active?

      # Multimedia toolbox
      ffmpeg

      # documents
      visidata
      # texlive.combined.scheme-full
      # TODO Convert existing LaTeX documents into using Nix build system
      # texlive is big and not that much used, sooo
      pdftk
      hunspell
      hunspellDicts.en_GB-ize
      hunspellDicts.en_US
      hunspellDicts.fr-moderne
      hunspellDicts.nl_NL
      # TODO libreoffice-extension-languagetool or libreoffice-extension-grammalecte-fr

    ] ++ lib.optionals config.frogeye.desktop.xorg [

      # multimedia editors
      gimp
      inkscape
      darktable
      puddletag
      audacity

      # downloading
      transmission-qt
    # wine only makes sense on x86_64
    ] ++ lib.optionals pkgs.stdenv.isx86_64 [
      wine
      # TODO wine-gecko wine-mono lib32-libpulse (?)

    ] ++ lib.optionals (!stdenv.isAarch64) [
      # Musescore is broken on aarch64
      musescore
      # Blender 4.0.1 can't compile on aarch64
      # https://hydra.nixos.org/job/nixos/release-23.11/nixpkgs.blender.aarch64-linux
      blender
    ]);
    services = {
      syncthing.enable = true;
    };
  };
}
